@@ -5,7 +5,7 @@ import logging
 import math
 from datetime import datetime
 from .parameter import Parameter
-from .tools import handle_date, handle_db_to_list, handle_db_dict, handle_db_id, handle_db_remove
+from .tools import handle_date, handle_db_to_list, handle_db_dict, handle_db_id, handle_db_remove, handle_abnormal
 from flask import abort, Response
 from bson import ObjectId
 
@@ -16,9 +16,9 @@ logging.basicConfig(
 
 
 class DBConnect:
-    def __init__(self, db: str, collection: str, home_kye='MONGODB_HOST', port_kye='MONGODB_PORT'):
-        self.mongo_home = os.environ.get(home_kye, None)
-        self.mongo_port = os.environ.get(port_kye, 27017)
+    def __init__(self, db: str, collection: str, home_key='MONGODB_HOST', port_key='MONGODB_PORT'):
+        self.mongo_home = os.environ.get(home_key, None)
+        self.mongo_port = os.environ.get(port_key, 27017)
 
         if not self.mongo_home or not self.mongo_port:
             logging.error('MongoDB(组件)的组件连接信息是不完整的')
@@ -40,9 +40,11 @@ class DBConnect:
             new_data = self.mongo_collection.insert_one(docu)
             return str(new_data.inserted_id)
         except Exception as err:
-            str_data = 'MongoDB(组件)出现写入错误: {0}'.format(err)
-            logging.warning(str_data)
-            abort(Response(str_data, 500, {}))
+            handle_abnormal(
+                message='MongoDB(组件)出现写入错误',
+                status=500,
+                other={'prompt': str(err)}
+            )
 
     def does_it_exist(self, docu: dict) -> bool:
         count = self.mongo_collection.count_documents(docu)
@@ -60,6 +62,8 @@ class DBConnect:
             # 重置更新时间
             if not modify_docu.__contains__('update_time'):
                 modify_docu['update_time'] = datetime.today()
+            # 将更新内容转化为mongo能识别的更新格式
+            modify_docu = {'$set':modify_docu}
             if many:
                 student = self.mongo_collection.update_many(
                     find_docu, modify_docu)
@@ -69,9 +73,11 @@ class DBConnect:
             # 返回匹配条数、受影响条数
             return {'matched_count': student.matched_count, 'modified_count': student.modified_count}
         except Exception as err:
-            str_data = 'MongoDB(组件)出现更新错误: {0}'.format(err)
-            logging.warning(str_data)
-            abort(Response(str_data, 500, {}))
+            handle_abnormal(
+                message='MongoDB(组件)出现更新错误',
+                status=500,
+                other={'prompt': str(err)}
+            )
 
     def delete_docu(self, find_docu: dict, many: bool = False, false_delete: bool = False) -> dict:
         try:
@@ -98,9 +104,11 @@ class DBConnect:
                 # 返回删除成功条数
                 return {'deleted_count': result.deleted_count, 'false_delete': false_delete}
         except Exception as err:
-            str_data = 'MongoDB(组件)出现删除错误: {0}'.format(err)
-            logging.warning(str_data)
-            abort(Response(str_data, 500, {}))
+            handle_abnormal(
+                message='MongoDB(组件)出现删除错误',
+                status=500,
+                other={'prompt': str(err)}
+            )
 
     def find_docu(self, find_dict: dict, many: bool = True) -> list:
         try:
@@ -117,9 +125,11 @@ class DBConnect:
                     return []
                 return [handle_db_dict(query_dict)]
         except Exception as err:
-            str_data = 'MongoDB(组件)出现查询错误: {0}'.format(err)
-            logging.warning(str_data)
-            abort(Response(str_data, 500, {}))
+            handle_abnormal(
+                message='MongoDB(组件)出现查询错误',
+                status=500,
+                other={'prompt': str(err)}
+            )
 
     def find_docu_by_id(self, id: str, raise_err=True) -> dict:
         """
@@ -129,13 +139,17 @@ class DBConnect:
         :return: 将结果转换为字典
         """
         if not isinstance(id, str):
-            logging.warning("类型错误，预期 %s ,却得到 %s" % (str, type(id)))
-            abort(Response("类型错误，预期 %s ,却得到 %s" % (str, type(id)), 400, {}))
+            handle_abnormal(
+                message='类型错误, 预期 %s ,却得到 %s' % (str, type(id)),
+                status=400,
+            )
         entity = self.find_docu({'id': id}, many=False)
         if entity is None or len(entity) == 0:
             if raise_err:
-                logging.warning('找不到 id= %s 的记录' % (id,))
-                abort(Response('找不到 id= %s 的记录' % (id,), 400, {}))
+                handle_abnormal(
+                    message='找不到 id= %s 的记录' % (id,),
+                    status=400,
+                )
             else:
                 return {}
         return entity[0]
@@ -147,9 +161,10 @@ class DBConnect:
         :return:
         """
         if not isinstance(id_list, list):
-            logging.warning("类型错误，预期 %s ,却得到 %s" % (list, type(id_list)))
-            abort(Response("类型错误，预期 %s ,却得到 %s" %
-                           (list, type(id_list)), 400, {}))
+            handle_abnormal(
+                message='类型错误, 预期 %s ,却得到 %s' % (list, type(id_list)),
+                status=400,
+            )
         id_search = []
         for id in id_list:
             id_search.append({'_id': ObjectId(id)})
@@ -198,7 +213,8 @@ class DBConnect:
                         find_dict['_id'] = ObjectId(str(filtered_value[i]))
                     else:
                         if filtered_value[i].strip() != '':
-                            find_dict[columns[i]] = {'$regex': filtered_value[i]}
+                            find_dict[columns[i]] = {
+                                '$regex': filtered_value[i]}
                     # 整理请求参数中的筛排序列表
                     if type(sort_order[i]) != str:
                         abort(Response('计算组件分页参数异常: 排序参数不支持 int 类型', 400, {}))
@@ -240,6 +256,8 @@ class DBConnect:
                 'remove_count': remove_count,
             }
         except Exception as err:
-            str_data = '计算组件分页参数异常: {0}'.format(err)
-            logging.warning(str_data)
-            abort(Response(str_data, 400, {}))
+            handle_abnormal(
+                message='计算组件分页参数异常',
+                status=400,
+                other={'prompt': str(err)}
+            )
