@@ -1,5 +1,8 @@
 import logging
 import time
+import json
+import socket
+from flask import abort, Response
 from datetime import datetime, timedelta
 from pymongo.cursor import Cursor
 from bson.objectid import ObjectId
@@ -23,9 +26,11 @@ def handle_date(date: str, date_type='start') -> datetime:
             if date_type == 'end' and date_data:
                 date_data += timedelta(hours=23, minutes=59, seconds=59)
     except Exception as err:
-        str_data = '日期字符串解析异常: {0}'.format(err)
-        logging.warning(str_data)
-        abort(Response(str_data, 400, {}))
+        handle_abnormal(
+            message='日期字符串解析异常',
+            status=400,
+            other={'prompt': str(err)}
+        )
 
 
 def handle_db_to_list(db_cursor: Cursor) -> list:
@@ -35,9 +40,10 @@ def handle_db_to_list(db_cursor: Cursor) -> list:
     :return:转换后的列表
     """
     if not isinstance(db_cursor, Cursor):
-        str_data = '类型必须是 %s (获取类型为 %s)' % (Cursor, type(db_cursor))
-        logging.warning(str_data)
-        abort(Response(str_data, 500, {}))
+        handle_abnormal(
+            message='类型必须是 %s (获取类型为 %s)' % (Cursor, type(db_cursor)),
+            status=500,
+        )
     result = []
     for db in db_cursor:
         result.append(handle_db_dict(db_dict=db))
@@ -55,15 +61,19 @@ def handle_db_dict(db_dict: dict) -> dict:
             db_dict['update_time'].timetuple())) * 1000
         return db_dict
     except Exception as err:
-        str_data = 'MongoDB 数据字典解析异常: {0}'.format(err)
-        logging.warning(str_data)
-        abort(Response(str_data, 500, {}))
+        handle_abnormal(
+            message='MongoDB 数据字典解析异常',
+            status=500,
+            other={'prompt': str(err)}
+        )
 
 
 def handle_db_id(data_dict: dict) -> dict:
     if not isinstance(data_dict, dict):
-        logging.warning("类型错误，预期 %s ,却得到 %s" % (dict, type(id)))
-        abort(Response("类型错误，预期 %s ,却得到 %s" % (dict, type(id)), 400, {}))
+        handle_abnormal(
+            message='类型错误，预期 %s ,却得到 %s' % (dict, type(id)),
+            status=400,
+        )
     try:
         if data_dict.__contains__('_id') and isinstance(data_dict['_id'], str):
             data_dict['_id'] = ObjectId(str(data_dict['_id']))
@@ -75,9 +85,11 @@ def handle_db_id(data_dict: dict) -> dict:
             del data_dict['id']
         return data_dict
     except Exception as err:
-        str_data = 'MongoDB _id 格式解析异常: {0}'.format(err)
-        logging.warning(str_data)
-        abort(Response(str_data, 400, {}))
+        handle_abnormal(
+            message='MongoDB _id 格式解析异常',
+            status=400,
+            other={'prompt': str(err)}
+        )
 
 
 def handle_db_remove(find_dict: dict) -> dict:
@@ -88,6 +100,24 @@ def handle_db_remove(find_dict: dict) -> dict:
         # 返回设置后的搜索条件
         return find_dict
     except Exception as err:
-        str_data = 'MongoDB 移除数据处理异常: {0}'.format(err)
-        logging.warning(str_data)
-        abort(Response(str_data, 500, {}))
+        handle_abnormal(
+            message='MongoDB 移除数据处理异常',
+            status=500,
+            other={'prompt': str(err)}
+        )
+
+
+def handle_abnormal(message: str, status: int, header: dict = {'Content-Type': 'application/json'}, other: dict = {}, is_raw: bool = False):
+    logging.warning(message)
+    host_name = socket.gethostname()
+    return_body = {
+        'message': message,
+        'server_time': int(datetime.today().strftime('%Y%m%d%H%M%S')) * 1000,
+        'host_name': host_name,
+        'host_ip': socket.gethostbyname(host_name),
+    }
+    return_body.update(other)
+    if is_raw:
+        return return_body, status, header
+    else:
+        abort(Response(json.dumps(return_body), status, header))
